@@ -1,10 +1,12 @@
 from andes.models.exciter.ac8b import AC8B  # NOQA
 from andes.models.exciter.esac1a import ESAC1A  # NOQA
+from andes.models.exciter.esdc1a import ESDC1A  # NOQA
 from andes.models.exciter.esdc2a import ESDC2A  # NOQA
 from andes.models.exciter.esst1a import ESST1A  # NOQA
 from andes.models.exciter.esst3a import ESST3A  # NOQA
 from andes.models.exciter.esst4b import ESST4B  # NOQA
 from andes.models.exciter.exac1 import EXAC1  # NOQA
+from andes.models.exciter.exac2 import EXAC2  # NOQA
 from andes.models.exciter.exac4 import EXAC4  # NOQA
 from andes.models.exciter.exdc2 import EXDC2  # NOQA
 from andes.models.exciter.exst1 import EXST1  # NOQA
@@ -13,3 +15,4 @@ from andes.models.exciter.ieeet3 import IEEET3  # NOQA
 from andes.models.exciter.ieeex1 import IEEEX1  # NOQA
 from andes.models.exciter.saturation import ExcExpSat, ExcQuadSat  # NOQA
 from andes.models.exciter.sexs import SEXS  # NOQA
+from andes.models.exciter.esac5a import ESAC5A  # NOQA
