@@ -6,3 +6,5 @@ from andes.models.experimental.fixed import FixedGen  # NOQA
 from andes.models.experimental.picontroller import PI2  # NOQA
 from andes.models.experimental.testmodel import TestDB1, TestPI, TestLagAWFreeze  # NOQA
 from andes.models.experimental.genrouos import GENROUOS  # NOQA
+from andes.models.experimental.regca1os import REGCA1OS  # NOQA
+from andes.models.experimental.reeca1os import REECA1OS  # NOQA
