@@ -5,4 +5,4 @@ Measurement device classes
 from andes.models.measurement.busfreq import BusFreq  # noqa
 from andes.models.measurement.busrocof import BusROCOF  # noqa
 from andes.models.measurement.pmu import PMU   # noqa
-from andes.models.measurement.pll import PLL1  # noqa
+from andes.models.measurement.pll import PLL1, PLL2  # noqa
