@@ -7,7 +7,7 @@ import logging
 import numpy as np
 
 from andes.core import (ModelData, IdxParam, Model, ExtParam,
-                        ExtState, ExtService, ExtAlgeb, Algeb)
+                        ExtState, ExtService, ExtAlgeb, Algeb, ConstService)
 from andes.core.service import Replace, DataSelect, DeviceFinder
 
 logger = logging.getLogger(__name__)
@@ -29,6 +29,18 @@ class PSSBase(Model):
         self.group = 'PSS'
         self.flags.update({'tds': True})
 
+        # from synchronous exciters, get ue
+        self.uee = ExtService(model='Exciter',
+                              src='ue',
+                              indexer=self.avr,
+                              tex_name=r'u_{ee}',
+                              info='Effective exciter online status',
+                              )
+        self.ue = ConstService(v_str='u * uee',
+                               info="effective connection status considering exciter's",
+                               tex_name='u_{e}',
+                               )
+
         self.VCUr = Replace(self.VCU, lambda x: np.equal(x, 0.0), 999)
         self.VCLr = Replace(self.VCL, lambda x: np.equal(x, 0.0), -999)
 
@@ -83,7 +95,7 @@ class PSSBase(Model):
         # from Exciter
         self.vi = ExtAlgeb(model='Exciter', src='vi', indexer=self.avr, tex_name='v_i',
                            info='Exciter input voltage',
-                           e_str='u * vsout',
+                           e_str='ue * vsout',
                            ename='Vi',
                            tex_ename='V_i',
                            is_input=True,
