@@ -5,6 +5,8 @@ Module for renewable energy generator (converter) model A.
 from andes.core import (Algeb, ConstService, ExtAlgeb, ExtParam, ExtService,
                         IdxParam, Lag, Model, ModelData, NumParam, Piecewise,)
 from andes.core.block import GainLimiter, LagAntiWindupRate
+from andes.core.service import PostInitService
+from andes.core.var import AliasAlgeb
 
 
 class REGCA1Data(ModelData):
@@ -51,7 +53,7 @@ class REGCA1Data(ModelData):
                                )
 
         self.Lvpl1 = NumParam(default=1.0, tex_name='L_{vpl1}',
-                              info='LVPL gain',
+                              info='LVPL gain at Brkpt',
                               unit='p.u',
                               )
         self.Volim = NumParam(default=1.2, tex_name='V_{olim}',
@@ -133,6 +135,8 @@ class REGCA1Model(Model):
                           tex_ename='Q',
                           )
 
+        self.vd = AliasAlgeb(self.v)
+
         self.p0s = ExtService(model='StaticGen',
                               src='p',
                               indexer=self.gen,
@@ -191,11 +195,14 @@ class REGCA1Model(Model):
         # `Ipcmd` is not defined when the initial `LVG_y` is zero
         self.Ipcmd = Algeb(tex_name='I_{pcmd}',
                            info='current component for active power',
-                           e_str='Ipcmd0 - Ipcmd * LVG_y',
+                           e_str='Ipcmd0_LVG - Ipcmd',
                            v_str='Indicator(LVG_y>0) * Ipcmd0 / LVG_y + Indicator(LVG_y<=0) * 1',
                            diag_eps=True,
                            )
 
+        self.Ipcmd0_LVG = PostInitService(v_str='Ipcmd',
+                                          info='initial Ipcmd considering initial LVG output')
+
         self.Iqcmd = Algeb(tex_name='I_{qcmd}',
                            info='current component for reactive power',
                            e_str='Iqcmd0 - Iqcmd', v_str='Iqcmd0')
@@ -284,7 +291,7 @@ class REGCA1(REGCA1Data, REGCA1Model):
     """
     Renewable energy generator model type A.
 
-    Implements ``REGCA1`` in PSS/E, or ``REGC_A`` in PSLF.
+    Implements ``REGCA1`` in PSS/E, or ``REGC_A`` in PSLF and Powerworld.
 
     Volim is the voltage limit for high voltage reactive current management,
     which should be large than static bus voltage (Volim > v),
