@@ -306,7 +306,7 @@ class DAE:
 
     def __init__(self, system):
         self.system = system
-        self.t = np.array(0.0, dtype=float)
+        self.t = np.array(-1.0, dtype=float)
         self.ts = DAETimeSeries(self)
         self.kcount = 0  # time step count
 
